#  File tests/constraint_conflict.R in package ergm, part of the Statnet suite
#  of packages for network analysis, http://statnet.org .
#
#  This software is distributed under the GPL-3 license.  It is free,
#  open source, and has the attribution requirements (GPL Section 7) at
#  http://statnet.org/attribution
#
#  Copyright 2003-2015 Statnet Commons
#######################################################################
library(ergm)
data(florentine)

efit <- ergm(flomarriage~edges, constraints=~edges)

stopifnot(length(warnings())==1)
